==> openshift-model-operatorhub-5.8.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SpecDescriptorFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class SpecDescriptorFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.SpecDescriptorFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.SpecDescriptorFluent<A>{
  public SpecDescriptorFluentImpl() {
  }
  public SpecDescriptorFluentImpl(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SpecDescriptor instance) {
    this.withDescription(instance.getDescription()); 
    this.withDisplayName(instance.getDisplayName()); 
    this.withPath(instance.getPath()); 
    this.withValue(instance.getValue()); 
    this.withXDescriptors(instance.getXDescriptors()); 
  }
  private java.lang.String description;
  private java.lang.String displayName;
  private java.lang.String path;
  private java.lang.String value;
  private java.util.List<java.lang.String> xDescriptors = new java.util.ArrayList<java.lang.String>();
  public java.lang.String getDescription() {
    return this.description;
  }
  public A withDescription(java.lang.String description) {
    this.description=description; return (A) this;
  }
  public java.lang.Boolean hasDescription() {
    return this.description != null;
  }
  
  /**
   * Method is deprecated. use withDescription instead.
   */
  @java.lang.Deprecated
  public A withNewDescription(java.lang.String arg0) {
    return (A)withDescription(new String(arg0));
  }
  public java.lang.String getDisplayName() {
    return this.displayName;
  }
  public A withDisplayName(java.lang.String displayName) {
    this.displayName=displayName; return (A) this;
  }
  public java.lang.Boolean hasDisplayName() {
    return this.displayName != null;
  }
  
  /**
   * Method is deprecated. use withDisplayName instead.
   */
  @java.lang.Deprecated
  public A withNewDisplayName(java.lang.String arg0) {
    return (A)withDisplayName(new String(arg0));
  }
  public java.lang.String getPath() {
    return this.path;
  }
  public A withPath(java.lang.String path) {
    this.path=path; return (A) this;
  }
  public java.lang.Boolean hasPath() {
    return this.path != null;
  }
  
  /**
   * Method is deprecated. use withPath instead.
   */
  @java.lang.Deprecated
  public A withNewPath(java.lang.String arg0) {
    return (A)withPath(new String(arg0));
  }
  public java.lang.String getValue() {
    return this.value;
  }
  public A withValue(java.lang.String value) {
    this.value=value; return (A) this;
  }
  public java.lang.Boolean hasValue() {
    return this.value != null;
  }
  
  /**
   * Method is deprecated. use withValue instead.
   */
  @java.lang.Deprecated
  public A withNewValue(java.lang.String arg0) {
    return (A)withValue(new String(arg0));
  }
  public A addToXDescriptors(java.lang.Integer index,java.lang.String item) {
    if (this.xDescriptors == null) {this.xDescriptors = new java.util.ArrayList<java.lang.String>();}
    this.xDescriptors.add(index, item);
    return (A)this;
  }
  public A setToXDescriptors(java.lang.Integer index,java.lang.String item) {
    if (this.xDescriptors == null) {this.xDescriptors = new java.util.ArrayList<java.lang.String>();}
    this.xDescriptors.set(index, item); return (A)this;
  }
  public A addToXDescriptors(java.lang.String... items) {
    if (this.xDescriptors == null) {this.xDescriptors = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.xDescriptors.add(item);} return (A)this;
  }
  public A addAllToXDescriptors(java.util.Collection<java.lang.String> items) {
    if (this.xDescriptors == null) {this.xDescriptors = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.xDescriptors.add(item);} return (A)this;
  }
  public A removeFromXDescriptors(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.xDescriptors!= null){ this.xDescriptors.remove(item);}} return (A)this;
  }
  public A removeAllFromXDescriptors(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.xDescriptors!= null){ this.xDescriptors.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getXDescriptors() {
    return this.xDescriptors;
  }
  public java.lang.String getXDescriptor(java.lang.Integer index) {
    return this.xDescriptors.get(index);
  }
  public java.lang.String getFirstXDescriptor() {
    return this.xDescriptors.get(0);
  }
  public java.lang.String getLastXDescriptor() {
    return this.xDescriptors.get(xDescriptors.size() - 1);
  }
  public java.lang.String getMatchingXDescriptor(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: xDescriptors) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingXDescriptor(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: xDescriptors) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withXDescriptors(java.util.List<java.lang.String> xDescriptors) {
    if (xDescriptors != null) {this.xDescriptors = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : xDescriptors){this.addToXDescriptors(item);}} else { this.xDescriptors = null;} return (A) this;
  }
  public A withXDescriptors(java.lang.String... xDescriptors) {
    if (this.xDescriptors != null) {this.xDescriptors.clear();}
    if (xDescriptors != null) {for (java.lang.String item :xDescriptors){ this.addToXDescriptors(item);}} return (A) this;
  }
  public java.lang.Boolean hasXDescriptors() {
    return xDescriptors != null && !xDescriptors.isEmpty();
  }
  public A addNewXDescriptor(java.lang.String arg0) {
    return (A)addToXDescriptors(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SpecDescriptorFluentImpl that = (SpecDescriptorFluentImpl) o;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    if (displayName != null ? !displayName.equals(that.displayName) :that.displayName != null) return false;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (value != null ? !value.equals(that.value) :that.value != null) return false;
    if (xDescriptors != null ? !xDescriptors.equals(that.xDescriptors) :that.xDescriptors != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(description,  displayName,  path,  value,  xDescriptors,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-5.11.2-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SpecDescriptorFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class SpecDescriptorFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.SpecDescriptorFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.SpecDescriptorFluent<A>{
  public SpecDescriptorFluentImpl() {
  }
  public SpecDescriptorFluentImpl(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SpecDescriptor instance) {
    this.withDescription(instance.getDescription()); 
    this.withDisplayName(instance.getDisplayName()); 
    this.withPath(instance.getPath()); 
    this.withValue(instance.getValue()); 
    this.withXDescriptors(instance.getXDescriptors()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String description;
  private java.lang.String displayName;
  private java.lang.String path;
  private java.lang.String value;
  private java.util.List<java.lang.String> xDescriptors = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDescription() {
    return this.description;
  }
  public A withDescription(java.lang.String description) {
    this.description=description; return (A) this;
  }
  public java.lang.Boolean hasDescription() {
    return this.description != null;
  }
  
  /**
   * Method is deprecated. use withDescription instead.
   */
  @java.lang.Deprecated
  public A withNewDescription(java.lang.String arg0) {
    return (A)withDescription(new String(arg0));
  }
  public java.lang.String getDisplayName() {
    return this.displayName;
  }
  public A withDisplayName(java.lang.String displayName) {
    this.displayName=displayName; return (A) this;
  }
  public java.lang.Boolean hasDisplayName() {
    return this.displayName != null;
  }
  
  /**
   * Method is deprecated. use withDisplayName instead.
   */
  @java.lang.Deprecated
  public A withNewDisplayName(java.lang.String arg0) {
    return (A)withDisplayName(new String(arg0));
  }
  public java.lang.String getPath() {
    return this.path;
  }
  public A withPath(java.lang.String path) {
    this.path=path; return (A) this;
  }
  public java.lang.Boolean hasPath() {
    return this.path != null;
  }
  
  /**
   * Method is deprecated. use withPath instead.
   */
  @java.lang.Deprecated
  public A withNewPath(java.lang.String arg0) {
    return (A)withPath(new String(arg0));
  }
  public java.lang.String getValue() {
    return this.value;
  }
  public A withValue(java.lang.String value) {
    this.value=value; return (A) this;
  }
  public java.lang.Boolean hasValue() {
    return this.value != null;
  }
  
  /**
   * Method is deprecated. use withValue instead.
   */
  @java.lang.Deprecated
  public A withNewValue(java.lang.String arg0) {
    return (A)withValue(new String(arg0));
  }
  public A addToXDescriptors(java.lang.Integer index,java.lang.String item) {
    if (this.xDescriptors == null) {this.xDescriptors = new java.util.ArrayList<java.lang.String>();}
    this.xDescriptors.add(index, item);
    return (A)this;
  }
  public A setToXDescriptors(java.lang.Integer index,java.lang.String item) {
    if (this.xDescriptors == null) {this.xDescriptors = new java.util.ArrayList<java.lang.String>();}
    this.xDescriptors.set(index, item); return (A)this;
  }
  public A addToXDescriptors(java.lang.String... items) {
    if (this.xDescriptors == null) {this.xDescriptors = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.xDescriptors.add(item);} return (A)this;
  }
  public A addAllToXDescriptors(java.util.Collection<java.lang.String> items) {
    if (this.xDescriptors == null) {this.xDescriptors = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.xDescriptors.add(item);} return (A)this;
  }
  public A removeFromXDescriptors(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.xDescriptors!= null){ this.xDescriptors.remove(item);}} return (A)this;
  }
  public A removeAllFromXDescriptors(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.xDescriptors!= null){ this.xDescriptors.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getXDescriptors() {
    return this.xDescriptors;
  }
  public java.lang.String getXDescriptor(java.lang.Integer index) {
    return this.xDescriptors.get(index);
  }
  public java.lang.String getFirstXDescriptor() {
    return this.xDescriptors.get(0);
  }
  public java.lang.String getLastXDescriptor() {
    return this.xDescriptors.get(xDescriptors.size() - 1);
  }
  public java.lang.String getMatchingXDescriptor(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: xDescriptors) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingXDescriptor(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: xDescriptors) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withXDescriptors(java.util.List<java.lang.String> xDescriptors) {
    if (xDescriptors != null) {this.xDescriptors = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : xDescriptors){this.addToXDescriptors(item);}} else { this.xDescriptors = null;} return (A) this;
  }
  public A withXDescriptors(java.lang.String... xDescriptors) {
    if (this.xDescriptors != null) {this.xDescriptors.clear();}
    if (xDescriptors != null) {for (java.lang.String item :xDescriptors){ this.addToXDescriptors(item);}} return (A) this;
  }
  public java.lang.Boolean hasXDescriptors() {
    return xDescriptors != null && !xDescriptors.isEmpty();
  }
  public A addNewXDescriptor(java.lang.String arg0) {
    return (A)addToXDescriptors(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SpecDescriptorFluentImpl that = (SpecDescriptorFluentImpl) o;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    if (displayName != null ? !displayName.equals(that.displayName) :that.displayName != null) return false;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (value != null ? !value.equals(that.value) :that.value != null) return false;
    if (xDescriptors != null ? !xDescriptors.equals(that.xDescriptors) :that.xDescriptors != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(description,  displayName,  path,  value,  xDescriptors,  additionalProperties,  super.hashCode());
  }
  
}
